<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Pashmina
 */

get_header(); ?>

    <?php if ( get_theme_mod( 'featured_posts' ) != '' ) : ?>

	<div class="container">
		<div class="row">
			<div class="col-lg-12">
                <div class="dt-featured-post-slider">
                    <div class="swiper-wrapper">

                        <?php
                        $dt_featured_posts      = esc_html( get_theme_mod( 'featured_posts_select' ) );
                        $featured_posts_count   = esc_html( get_theme_mod( 'featured_posts_count' ) );

                        if ( $dt_featured_posts == '' ) {
                            $dt_featured_posts = '';
                        }

                        $args = array(
                            'post_type'		 => 'post',
                            'posts_per_page' => $featured_posts_count,
                            'orderby' 		 => 'ASC',
                            'category__in'   => $dt_featured_posts
                        );

                        $dt_featured_posts = new WP_Query($args);

                        while ( $dt_featured_posts->have_posts() ) : $dt_featured_posts->the_post(); ?>

                            <div class="swiper-slide">
                                <div class="dt-featured-post">
                                    <figure>

                                        <?php

                                        if ( has_post_thumbnail() ) :

                                            the_post_thumbnail( 'pashmina-featured-post-img' );

                                        else : ?>
                                            <img src="<?php echo esc_url( get_template_directory_uri() ); ?>/images/blank.png" alt="<?php _e( 'no image found', 'pashmina' )?>"/>
                                        <?php endif; ?>

                                        <span class="transition5"><a href="<?php esc_url( the_permalink() ); ?>" title="<?php the_title_attribute(); ?>"><i class="fa fa-mail-forward transition5"></i></a> </span>
                                    </figure>

                                    <div class="entry-footer">
                                        <h3><a href="<?php esc_url( the_permalink() ); ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></h3>

                                        <span><?php esc_attr( the_date() ); ?></span>
                                    </div>
                                </div><!-- .dt-featured-post -->
                            </div><!-- .swiper-slide -->

                        <?php endwhile; ?>

                        <?php wp_reset_postdata(); ?>

                        <div class="clearfix"></div>
                    </div><!-- .swiper-wrapper -->

                    <!-- Add Pagination -->
                    <div class="swiper-pagination"></div>
                </div><!-- .dt-featured-post-slider -->
			</div><!-- .col-lg-12 -->
		</div><!-- .row -->
	</div><!-- .container -->

    <?php else : ?>

    <div class="dt-slider-separator"></div>

    <?php endif; ?>

    <div class="container">
        <div class="row">
            <div class="col-lg-8 col-md-8">

                <main id="main" class="site-main" role="main">
                    <?php if ( have_posts() ) :

                        while ( have_posts() ) : the_post();

                                get_template_part( 'template-parts/content', get_post_format() );


                        endwhile; ?>

                        <?php wp_reset_postdata(); ?>

                        <div class="clearfix"></div>

                        <div class="dt-pagination-nav">
                            <?php echo paginate_links(); ?>
                        </div><!---- .dt-pagination-nav ---->

                    <?php else : ?>

                        <p><?php _e( 'Sorry, no posts matched your criteria.', 'pashmina' ); ?></p>

                    <?php endif; ?>
                </main>

            </div>

            <aside class="col-lg-4 col-md-4">
                <div class="dt-sidebar">
                    <?php get_sidebar(); ?>
                </div><!-- dt-sidebar -->
            </aside><!-- .col-lg-4 -->
        </div>
    </div>

<?php
get_footer();
